﻿using System;
using System.Linq;

using DevExpress.Data;
using DevExpress.Utils;
using DevExpress.Utils.Menu;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Columns;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                          // Multi Select
                GridMultiSelectMode.RowSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,  // Draw Focus Rect Style
                true,                          // Show Indicator
                true,                          // Show Column Headers
                true,                          // Allow Column Moving
                true,                          // Allow Column Resizing
                true,                          // Allow Filter
                true,                          // Allow Sort
                false,                         // Allow Cell Merge
                EditorShowMode.Default,        // Editor Show Mode
                false                          // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsMenu.EnableColumnMenu = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();

            this.gridView.BestFitColumns();

            this.gridView.PopupMenuShowing += gridView_PopupMenuShowing;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 메뉴 항목 클릭시 처리하기 - menuItem_Click(sender, e)

        /// <summary>
        /// 메뉴 항목 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void menuItem_Click(object sender, EventArgs e)
        {
            this.gridView.SortInfo.ClearAndAddRange
            (
                new GridColumnSortInfo[]
                {
                    new GridColumnSortInfo(this.gridView.Columns["UnitPrice"], ColumnSortOrder.Ascending)
                }
            );
        }

        #endregion
        #region 그리드 뷰 팝업 메뉴 표시시 처리하기 - gridView_PopupMenuShowing(sender, e)

        /// <summary>
        /// 그리드 뷰 팝업 메뉴 표시시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_PopupMenuShowing(object sender, PopupMenuShowingEventArgs e)
        {
            DXMenuItem menuItem = e.Menu.Items.FirstOrDefault(x => x.Caption == "Clear All Sorting");

            if(menuItem != null)
            {
                menuItem.Click -= menuItem_Click;
                menuItem.Click += menuItem_Click;
            }
        }

        #endregion
    }
}